#ifndef HELPERS_H
#define HELPERS_H

typedef struct Helper {
	gchar *path;
	gchar *mime_type;
	gchar *icon;
} Helper;


Helper* screem_helper_new( void );
void    screem_helper_destroy( Helper *helper );

Helper* screem_helper_locate( gchar *path );
void    screem_helper_add( Helper *helper );
Helper* screem_helper_remove( gchar *path );

void screem_helper_execute( gchar *path );


GtkWidget *screem_helper_menu( void );

void screem_helpers_build_toolbar( void );

void edit_helper_scripts( void );


#endif
